@@ -5,7 +5,7 @@ use Encode qw(decode);
 use base 'Exporter';
 our @EXPORT = qw(convert_to_ascii);
 our @EXPORT_OK = qw(convert_to_ascii);
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 my %char_map;
 
 =encoding utf8
@@ -3777,7 +3777,7 @@ FFEE 6F
 1D7C9 77
 1D7CA 46
 1D7CB 66
-1D7CE 4F
+1D7CE 30
 1D7CF 31
 1D7D0 32
 1D7D1 33
@@ -3787,7 +3787,7 @@ FFEE 6F
 1D7D5 37
 1D7D6 38
 1D7D7 39
-1D7D8 4F
+1D7D8 30
 1D7D9 31
 1D7DA 32
 1D7DB 33
@@ -3797,7 +3797,7 @@ FFEE 6F
 1D7DF 37
 1D7E0 38
 1D7E1 39
-1D7E2 4F
+1D7E2 30
 1D7E3 31
 1D7E4 32
 1D7E5 33
@@ -3807,7 +3807,7 @@ FFEE 6F
 1D7E9 37
 1D7EA 38
 1D7EB 39
-1D7EC 4F
+1D7EC 30
 1D7ED 31
 1D7EE 32
 1D7EF 33
@@ -3817,7 +3817,7 @@ FFEE 6F
 1D7F3 37
 1D7F4 38
 1D7F5 39
-1D7F6 4F
+1D7F6 30
 1D7F7 31
 1D7F8 32
 1D7F9 33
